@@ -39,7 +39,33 @@ class EnterpriseEnrollmentFactory(factory.django.DjangoModelFactory):
     course_id = factory.lazy_attribute(lambda x: FAKER.slug())  # pylint: disable=no-member
     enrollment_created_timestamp = factory.lazy_attribute(lambda x: '2018-01-01T00:00:00Z')
     user_current_enrollment_mode = factory.lazy_attribute(lambda x: 'verified')
-    has_passed = False
+    has_passed = factory.lazy_attribute(lambda x: FAKER.boolean())  # pylint: disable=no-member
+    consent_granted = True
+    course_title = factory.lazy_attribute(lambda x: ' '.join(FAKER.words(nb=2)).title())  # pylint: disable=no-member
+    course_start = factory.lazy_attribute(lambda x: FAKER.date_time_between(  # pylint: disable=no-member
+        start_date='-2M',
+        end_date='+2M',
+        tzinfo=pytz.utc))
+    user_email = factory.lazy_attribute(lambda x: FAKER.email())  # pylint: disable=no-member
+    current_grade = factory.lazy_attribute(
+        lambda x: FAKER.pyfloat(right_digits=2, min_value=0, max_value=1))  # pylint: disable=no-member
+
+    @factory.lazy_attribute
+    def course_end(self):
+        return FAKER.date_time_between(   # pylint: disable=no-member
+            start_date=self.course_start,
+            end_date="+8M",
+            tzinfo=pytz.utc)
+
+    @factory.lazy_attribute
+    def passed_timestamp(self):
+        """ Create a passed timestamp if a course has been passed """
+        if self.has_passed:
+            return FAKER.date_time_between(  # pylint: disable=no-member
+                start_date=self.course_start,
+                end_date=self.course_end,
+                tzinfo=pytz.utc)
+        return None
 
 
 class UserFactory(factory.django.DjangoModelFactory):
@@ -54,10 +80,10 @@ class UserFactory(factory.django.DjangoModelFactory):
 
     _DEFAULT_PASSWORD = 'test'
 
-    username = factory.Sequence(u'robot{0}'.format)
-    email = factory.Sequence(u'robot+test+{0}@edx.org'.format)
+    username = factory.Sequence('robot{0}'.format)
+    email = factory.Sequence('robot+test+{0}@edx.org'.format)
     password = factory.PostGenerationMethodCall('set_password', _DEFAULT_PASSWORD)
-    first_name = factory.Sequence(u'Robot{0}'.format)
+    first_name = factory.Sequence('Robot{0}'.format)
     last_name = 'Test'
     is_staff = factory.lazy_attribute(lambda x: False)
     is_active = True
@@ -80,8 +106,8 @@ class EnterpriseUserFactory(factory.django.DjangoModelFactory):
     enterprise_user_id = factory.lazy_attribute(lambda x: FAKER.random_int(min=1))  # pylint: disable=no-member
     enterprise_sso_uid = factory.lazy_attribute(lambda x: FAKER.text(max_nb_chars=255))  # pylint: disable=no-member
     user_account_creation_timestamp = datetime(2011, 1, 1, tzinfo=pytz.utc)
-    user_username = factory.Sequence(u'robot{0}'.format)
-    user_email = factory.Sequence(u'robot+test+{0}@edx.org'.format)
+    user_username = factory.Sequence('robot{0}'.format)
+    user_email = factory.lazy_attribute(lambda x: FAKER.email())  # pylint: disable=no-member
     user_country_code = factory.lazy_attribute(lambda x: FAKER.country_code())  # pylint: disable=no-member
     last_activity_date = datetime(2012, 1, 1).date()
 
